.\"	$NetBSD: mkdep.1,v 1.18 2013/03/05 01:59:56 christos Exp $
.\"
.\" Copyright (c) 1987, 1990, 1993
.\"	The Regents of the University of California.  All rights reserved.
.\"
.\" Redistribution and use in source and binary forms, with or without
.\" modification, are permitted provided that the following conditions
.\" are met:
.\" 1. Redistributions of source code must retain the above copyright
.\"    notice, this list of conditions and the following disclaimer.
.\" 2. Redistributions in binary form must reproduce the above copyright
.\"    notice, this list of conditions and the following disclaimer in the
.\"    documentation and/or other materials provided with the distribution.
.\" 3. Neither the name of the University nor the names of its contributors
.\"    may be used to endorse or promote products derived from this software
.\"    without specific prior written permission.
.\"
.\" THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
.\" ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
.\" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
.\" ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
.\" FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
.\" DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
.\" OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
.\" HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
.\" LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
.\" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
.\" SUCH DAMAGE.
.\"
.\"     @(#)mkdep.1	8.1 (Berkeley) 6/6/93
.\"
.Dd March 4, 2013
.Dt MKDEP 1
.Os
.Sh NAME
.Nm mkdep
.Nd construct Makefile dependency list
.Sh SYNOPSIS
.Nm
.Op Fl aDdiopqv
.Op Fl f Ar file
.Op Fl P Ar prefix
.Op Fl s Ar suffixes
.Li --
.Op Ar flags
.Ar file ...
.Sh DESCRIPTION
.Nm
takes a set of flags for the C compiler and a list
of C source files as arguments and constructs a set of include
file dependencies which are written into the file ``.depend''.
An example of its use in a Makefile might be:
.Bd -literal -offset indent
CFLAGS= -O -I../include
SRCS= file1.c file2.c

depend:
	mkdep -- ${CFLAGS} ${SRCS}
.Ed
.Pp
where the macro SRCS is the list of C source files and the macro
CFLAGS is the list of flags for the C compiler.
.Pp
The options are as follows:
.Bl -tag -width Ds
.It Fl a
Append to the output file,
so that multiple
.Nm Ns 's
may be run from a single Makefile.
.It Fl D
Post process (as
.Fl d )
but read the list of filenames from stdin.
.It Fl d
Post process and merge previously created (for example by
.Dq cc -MD x.c )
depend files into a single file.
.It Fl f
Write the include file dependencies to
.Ar file ,
instead of the default ``.depend''.
.It Fl i
When
.Fl d
or
.Fl D
is used, instead of inlining the contents of the files to the resulting
depend file, use include statements to include the source dependency files.
.It Fl o
Add an additional .OPTIONAL line for each dependent file.
.It Fl P
Prepend the string given in
.Ar prefix
to every target filename.
This is useful for programs that have source files in multiple subdirectories
and a single Makefile that references all of them explicitly (without using
the VPATH functionality because there can be files with the same name in
each subdirectory).
.It Fl p
Cause
.Nm
to produce dependencies of the form:
.Bd -literal -offset indent
program: program.c
.Ed
.Pp
so that subsequent makes will produce
.Ar program
directly from its C module rather than using an intermediate
.Pa \&.o
module.
This is useful for programs whose source is contained in a single
module.
.Fl p
is equivalent to specifying a null suffix with
.Fl s .
.It Fl q
Do not print a warning for inaccessible files when
.Fl d
is given.
.It Fl s
Expand each target filename to a list, replacing the
.Ql \&.o
suffix with each element of
.Ar suffixes .
The list of suffixes may be space or comma separated.
.It Fl v
print debugging output.
.El
.Sh FILES
.Bl -tag -width .depend -compact
.It Pa .depend
File containing list of dependencies.
.El
.Sh SEE ALSO
.Xr cc 1 ,
.Xr cpp 1 ,
.Xr make 1
.Sh HISTORY
The
.Nm
command appeared in
.Bx 4.3 Tahoe .
.Sh BUGS
Some characters special to
.Xr make 1 ,
most notably the comment character, are not escaped correctly if they
appear in file names.
This can lead to unparseable output or silently cause dependencies to
be lost.
.\" (This problem is actually in gcc -M.)
